@@ -95,7 +95,7 @@ void day_page_draw_background (const day_page_t page)
 	widget = page->widget;
 	pl = gtk_widget_create_pango_layout (widget, NULL);
 	white_gc = widget->style->white_gc;
-	gray_gc  = widget->style->bg_gc[GTK_STATE_NORMAL];
+	gray_gc  = pen_new(widget, 58905, 58905, 56610);
 	black_gc = widget->style->black_gc;
 	/* Row height */ 	
 	/* Draw the hour column */
@@ -133,7 +133,8 @@ void day_page_draw_background (const day_page_t page)
 	}
 	/* Draws the hours rectangle */
 	gdk_draw_rectangle(widget->window, black_gc, FALSE, 0,0, page->width/page->time_col_ratio, page->height-1);		
-	
+    
+    g_object_unref(gray_gc);
 }
 
 gboolean
@@ -166,7 +167,8 @@ button_press (GtkWidget *widget,
 				gint width, height;
 				found = TRUE;
 				sel_event = e_r->event;
-				char *buffer;
+				gchar *buffer = NULL;
+				gchar *tbuffer = NULL;
 				event_details_t evd;
 				struct tm start_tm, end_tm;
 				time_t end;
@@ -182,14 +184,18 @@ button_press (GtkWidget *widget,
 				          evd->summary, start_tm.tm_hour, start_tm.tm_min, 
 				          end_tm.tm_hour,end_tm.tm_min, 
 				          (e_r->event->flags & FLAG_ALARM ? "(A)":""), 
-				          evd->description);
-				buffer = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
+				          evd->description ? evd->description : "");
+				tbuffer = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
 				gtk_window_set_position (GTK_WINDOW (popup),GTK_WIN_POS_MOUSE);
 				gtk_window_set_default_size (GTK_WINDOW (popup), dr_->page->width/2, 
 				                             dr_->page->height*.8);
 				gtk_window_get_size (GTK_WINDOW (popup), &width, &height);
-				gtk_label_set_text (GTK_LABEL (event_infos_popup), buffer);
-                
+                if (buffer)
+    				gtk_label_set_text (GTK_LABEL (event_infos_popup), 
+                                        tbuffer ? tbuffer : buffer);
+                else
+    				gtk_label_set_text (GTK_LABEL (event_infos_popup), "");
+                    
                 /* check for available export methods */
                 if (export_bluetooth_available())
                   gtk_widget_show(send_bt_button);
@@ -202,8 +208,11 @@ button_press (GtkWidget *widget,
                   gtk_widget_hide(send_ir_button);
                 
 				gtk_widget_show (popup);
-				
-				g_free (buffer);
+
+				if (tbuffer) 
+                    g_free (tbuffer);
+				if (buffer) 
+                    g_free (buffer);
 				break;
 			}	
 		}
@@ -236,7 +245,7 @@ delete_event (event_t ev, GtkWidget *d)
   event_details_t ev_d;
   recur_t r;
   
-  ev_real = (event_t)ev->cloned_ev;
+  ev_real = get_cloned_ev(ev);
   ev_d = event_db_get_details (ev_real);
      
   if (ev_real->recur)
@@ -247,7 +256,7 @@ delete_event (event_t ev, GtkWidget *d)
         {			  
           if (ev_real->flags & FLAG_ALARM)
             {
-              unschedule_alarm (ev_real, d);
+              unschedule_alarm (ev_real, gtk_widget_get_toplevel(d));
               schedule_next (0,0, d);
             }
           event_db_remove (ev_real);
@@ -263,7 +272,7 @@ delete_event (event_t ev, GtkWidget *d)
     {			  
       if (ev_real->flags & FLAG_ALARM)
         {
-          unschedule_alarm (ev_real,d);
+          unschedule_alarm (ev_real, gtk_widget_get_toplevel(d));
           schedule_next (0,0,d);
         }
       event_db_remove (ev_real);
@@ -279,7 +288,7 @@ void day_view_expose ()
 	GdkGC *white_gc, *gray_gc, *black_gc;
 	gint width=0, height=0;
 	white_gc = draw->style->white_gc;
-	gray_gc = draw->style->bg_gc[GTK_STATE_NORMAL];
+	gray_gc  = pen_new(draw, 58905, 58905, 56610);
 	black_gc = draw->style->black_gc;
 		
 	gdk_window_get_size (draw->window, &width, &height);
@@ -299,6 +308,8 @@ void day_view_expose ()
 	
 	day_render_set_event_rectangles (dr);
 	draw_appointments (dr);
+    
+    g_object_unref(gray_gc);
 }
 
 gboolean
@@ -313,7 +324,7 @@ day_view_expose_cb (GtkWidget *widget,
 int 
 reminder_view_init ()
 {
-	GdkGC *white_gc, *gray_gc, *black_gc, *cream_gc;
+	GdkGC *white_gc, *black_gc, *cream_gc;
 
 	
 	time_t end, start;
@@ -351,7 +362,6 @@ reminder_view_init ()
 	
 	
 	white_gc = rem_area->style->white_gc;
-	gray_gc = rem_area->style->bg_gc[GTK_STATE_NORMAL];
 	black_gc = rem_area->style->black_gc;
 	
 	   
@@ -502,17 +512,19 @@ day_changed_calendar (GtkWidget *widget)
 }
 
 
-/* Go to hour h
+/* 
+ * Go to hour h
  * If h is negative it goes to the current hour
- *
  */
 void
 scroll_to (GtkWidget *scrolled, gint hour)
 {
 	GtkAdjustment *adj;
-	gint w = 0, h = 0;
+	gint h = 0;
+    gdouble upper, lower, value;
+    
 	/* Scroll to the current hour */
-	if(hour < 0)
+	if (hour < 0)
 	{
 		time_t now;
 		struct tm now_tm;
@@ -521,21 +533,15 @@ scroll_to (GtkWidget *scrolled, gint hour)
 		hour = MAX (now_tm.tm_hour - 1, 0) ;	
 	}
 		
-	gdouble page_increment, step_increment, page_size, upper, lower,value;
-	gtk_widget_get_size_request (draw, &w, &h);
-	
-	page_increment = h/2;	
-	step_increment = h/NUM_HOURS;
-	
-	page_size = h;
-	value = (gdouble)hour/NUM_HOURS *h;
+	gtk_widget_get_size_request (draw, NULL, &h);
+	value = (gdouble)hour/NUM_HOURS * h;
+	adj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(scrolled));
+    
 	lower  = 0.0;
 	upper = h;
 
-	adj = GTK_ADJUSTMENT(gtk_adjustment_new(value,lower,upper,step_increment, 
-	                     page_increment, page_size));
-	
-	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (scrolled), adj);
+    gtk_adjustment_clamp_page(adj, lower, upper);
+    gtk_adjustment_set_value(adj, value);
 }
 
 
@@ -583,8 +589,8 @@ destroy_popup (GtkWidget *widget, GdkEventButton *event, gpointer d)
 static void
 delete_event_cb (GtkWidget *widget, GtkWidget *a)
 {
-	delete_event (sel_event, widget);
 	gtk_widget_hide (popup);
+	delete_event (sel_event, widget);
 }
 
 
@@ -607,15 +613,15 @@ save_cb (GtkWidget *widget, GtkWidget *a)
 static void
 send_ir_cb (GtkWidget *widget, GtkWidget *a)
 {
-	vcal_do_send_irda (sel_event);
 	gtk_widget_hide (popup);
+	vcal_do_send_irda (sel_event);
 }
 
 static void
 send_bt_cb (GtkWidget *widget, GtkWidget *a)
 {
-	vcal_do_send_bluetooth (sel_event);
 	gtk_widget_hide (popup);
+	vcal_do_send_bluetooth (sel_event);
 }
 
 gboolean
@@ -641,11 +647,14 @@ day_view (void)
   GtkWidget *vbox_popup = gtk_vbox_new (FALSE, 0);
   gboolean landscape;
   gint 	win_width, win_height;
+  GtkWidget *frame;
+    
   /* Popup needed to show infos about an appointment */
-  
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   popup = gtk_window_new (GTK_WINDOW_POPUP);
-  event_infos_popup = gtk_label_new (_(""));
+  frame = gtk_frame_new(NULL);
+    
+  event_infos_popup = gtk_label_new ("");
   gtk_misc_set_alignment (GTK_MISC (event_infos_popup), 0, 0);
   gtk_misc_set_padding (GTK_MISC (event_infos_popup), gpe_get_border(), 
 	                    gpe_get_border());
@@ -673,15 +682,17 @@ day_view (void)
   gtk_button_set_alignment (GTK_BUTTON (send_bt_button), 0, 0.5);
   gtk_button_set_alignment (GTK_BUTTON (save_button), 0, 0.5);
 
-  gtk_container_add (GTK_CONTAINER (popup), vbox_popup);
-  gtk_box_pack_start (GTK_BOX (vbox_popup), event_infos_popup, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (popup), frame);
+  gtk_container_add (GTK_CONTAINER (frame), vbox_popup);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), event_infos_popup, FALSE, TRUE, 0);
   
-  gtk_box_pack_start (GTK_BOX (vbox_popup), edit_event_button, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox_popup), delete_event_button, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox_popup), save_button, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox_popup), send_ir_button, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox_popup), send_bt_button, TRUE, TRUE, 0);
-  gtk_widget_show_all (vbox_popup);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), edit_event_button, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), delete_event_button, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), save_button, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), send_ir_button, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_popup), send_bt_button, FALSE, TRUE, 0);
+  
+  gtk_widget_show_all (frame);
   
 
   gtk_widget_add_events (GTK_WIDGET (popup),
