@@ -54,6 +54,7 @@ struct edit_state
 
   GtkWidget *description;
   GtkWidget *summary;
+  GtkWidget *location;
 
   GtkWidget *radiobuttonforever, *radiobuttonendafter,
             *radiobuttonendon, *datecomboendon;
@@ -206,7 +207,7 @@ weekly_toggled (GtkWidget *widget,
 void
 unschedule_alarm (event_t ev, GtkWidget *d)
 {
-  event_t ev_real = (event_t)ev->cloned_ev;
+  event_t ev_real = get_cloned_ev(ev);
 
   if (!schedule_cancel_alarm (ev_real->uid, ev->start)) 
   {
@@ -243,7 +244,7 @@ schedule_next (guint skip, guint uid, GtkWidget *d)
 
       if (ev->flags & FLAG_ALARM) 
 	{
-	  ev_real = (event_t)ev->cloned_ev;
+	  ev_real = get_cloned_ev(ev);
 	  ev_d = event_db_get_details (ev_real);
 	  if (((int)(ev->start) != (int)skip) && (uid!=ev_real->uid))
 	    {
@@ -292,7 +293,7 @@ click_delete (GtkWidget *widget, GtkWidget *d)
   event_details_t ev_d;
   recur_t r;
   
-  ev_real = (event_t)ev->cloned_ev;
+  ev_real = get_cloned_ev(ev);
   ev_d = event_db_get_details (ev_real);
      
   if (ev_real->recur)
@@ -346,7 +347,7 @@ click_ok (GtkWidget *widget, GtkWidget *d)
     
   if (s->ev)
     {
-      ev = (event_t)(s->ev->cloned_ev);
+      ev = get_cloned_ev(s->ev);
       ev_d = event_db_get_details (ev);
       if (ev->flags & FLAG_ALARM)
         unschedule_alarm (s->ev, gtk_widget_get_toplevel(widget));
@@ -447,15 +448,19 @@ click_ok (GtkWidget *widget, GtkWidget *d)
     {
       GtkWidget* dialog;
       gint ret;
-      
+#ifdef IS_HILDON
+      dialog = hildon_note_new_confirmation (GTK_WINDOW(d),
+                       _("Event starts in the past!\nSave anyway?"));
+#else        
       dialog = gtk_message_dialog_new (GTK_WINDOW(d),
                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                        GTK_MESSAGE_WARNING,
                        GTK_BUTTONS_YES_NO,
                        _("Event starts in the past!\nSave anyway?"));
+#endif        
       ret = gtk_dialog_run (GTK_DIALOG(dialog));
       gtk_widget_destroy(dialog);
-      if (ret == GTK_RESPONSE_NO)
+      if ((ret == GTK_RESPONSE_NO) || (ret == GTK_RESPONSE_CANCEL))
         {
           event_db_destroy (ev);
           return;
@@ -475,8 +480,11 @@ click_ok (GtkWidget *widget, GtkWidget *d)
   if (ev_d->summary)
     g_free (ev_d->summary);
 
-  ev_d->summary = gtk_editable_get_chars (GTK_EDITABLE (s->summary),
-                                          0, -1);
+  ev_d->summary = gtk_editable_get_chars (GTK_EDITABLE (s->summary), 0, -1);
+  
+  if (ev_d->location)
+    g_free (ev_d->location);
+  ev_d->location = gtk_editable_get_chars (GTK_EDITABLE (s->location), 0, -1);
 
   g_slist_free (ev_d->categories);
   ev_d->categories = g_slist_copy (s->categories);
@@ -603,7 +611,7 @@ check_constrains(struct edit_state *s)
       time_t start_t, end_t;
       event_t ev;
       
-      ev = (event_t)(s->ev->cloned_ev);
+      ev = get_cloned_ev(s->ev);
       
       /* Appointment */
       char *start = gtk_editable_get_chars (GTK_EDITABLE (GTK_COMBO
@@ -715,11 +723,10 @@ click_categories (GtkWidget *b, GtkWidget *w)
   ui = gpe_pim_categories_dialog (s->categories, TRUE, G_CALLBACK (update_categories), s);
 #else
   ui = gpe_pim_categories_dialog (s->categories, G_CALLBACK (update_categories), s);
-
+#endif
   gtk_window_set_transient_for(GTK_WINDOW(ui),
                                GTK_WINDOW(gtk_widget_get_toplevel(b)));
   gtk_window_set_modal(GTK_WINDOW(ui), TRUE);
-#endif
 }
 
 gboolean
@@ -886,6 +893,7 @@ build_edit_event_window (void)
   GtkAdjustment *endspin_adj, *dailyspin_adj, *weeklyspin_adj,
                 *monthlyspin_adj, *yearlyspin_adj;
   GtkAdjustment *taskadj;
+  GtkWidget *locationlabel;
 
   /* End of declarations */
 
@@ -945,9 +953,6 @@ build_edit_event_window (void)
   s->optionmenutype   = gtk_simple_menu_new ();
   gtk_simple_menu_append_item (GTK_SIMPLE_MENU (s->optionmenutype), _("Appointment"));
   gtk_simple_menu_append_item (GTK_SIMPLE_MENU (s->optionmenutype), _("Reminder"));
-#if 0
-  gtk_simple_menu_append_item (GTK_SIMPLE_MENU (s->optionmenutype), _("Task"));
-#endif
   g_signal_connect (G_OBJECT (s->optionmenutype), "changed",
                     G_CALLBACK (set_notebook_page), s);
 
@@ -974,6 +979,9 @@ build_edit_event_window (void)
 
   starttime           = gtk_combo_new ();
   endtime             = gtk_combo_new ();
+  
+  gtk_widget_set_size_request (starttime, 42, -1);
+  gtk_widget_set_size_request (endtime, 42, -1);
 
   gtk_combo_set_popdown_strings (GTK_COMBO (starttime), times);
   gtk_combo_set_popdown_strings (GTK_COMBO (endtime), times);
@@ -987,7 +995,9 @@ build_edit_event_window (void)
   
   gtk_misc_set_alignment (GTK_MISC (startdatelabel), 0, 0.5);
   gtk_misc_set_alignment (GTK_MISC (enddatelabel), 0, 0.5);
-
+  gtk_misc_set_alignment (GTK_MISC (starttimelabel), 0, 0.5);
+  gtk_misc_set_alignment (GTK_MISC (endtimelabel), 0, 0.5);
+  
   s->startdate        = gtk_date_combo_new ();
   s->enddate          = gtk_date_combo_new ();
   s->reminderdate     = gtk_date_combo_new ();
@@ -1001,7 +1011,7 @@ build_edit_event_window (void)
   gtk_table_attach (GTK_TABLE (startendtable), startdatelabel, 0, 1, 0, 1,
                     0, 0, 0, boxspacing);
   gtk_table_attach (GTK_TABLE (startendtable), starttime, 1, 2, 0, 1,
-                    GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+                    GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
   gtk_table_attach (GTK_TABLE (startendtable), starttimelabel, 2, 3, 0, 1,
                     0, 0, 0, boxspacing);
   gtk_table_attach (GTK_TABLE (startendtable), s->startdate, 3, 4, 0, 1,
@@ -1009,7 +1019,7 @@ build_edit_event_window (void)
   gtk_table_attach (GTK_TABLE (startendtable), enddatelabel, 0, 1, 1, 2,
                     0, 0, 0, boxspacing);
   gtk_table_attach (GTK_TABLE (startendtable), endtime, 1, 2, 1, 2,
-                    GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+                    GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
   gtk_table_attach (GTK_TABLE (startendtable), endtimelabel, 2, 3, 1, 2,
                     0, 0, 0, boxspacing);
   gtk_table_attach (GTK_TABLE (startendtable), s->enddate, 3, 4, 1, 2,
@@ -1060,7 +1070,10 @@ build_edit_event_window (void)
   gtk_container_set_border_width (GTK_CONTAINER(detailtable), border);
   gtk_table_set_col_spacings (GTK_TABLE (detailtable), boxspacing);
   gtk_table_set_row_spacings (GTK_TABLE (detailtable), boxspacing);
-  
+  /* location  */  
+  locationlabel     = gtk_label_new (_("Location:"));
+  s->location       = gtk_entry_new ();
+  gtk_misc_set_alignment (GTK_MISC(locationlabel), 0, 0.5);
   /* Categories */
   catbutton = gtk_button_new_with_label (_("Categories"));
   catlabel = gtk_label_new (_("Define categories by tapping the Categories button."));
@@ -1086,13 +1099,17 @@ build_edit_event_window (void)
   gtk_misc_set_alignment(GTK_MISC (descriptionlabel), 0, 0.5);
   gtk_widget_set_size_request (GTK_WIDGET (description), -1, 68);
 
-  gtk_table_attach(GTK_TABLE(detailtable), catbutton, 0, 1, 0, 1, 
+  gtk_table_attach(GTK_TABLE(detailtable), locationlabel, 0, 1, 0, 1, 
                    GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(detailtable), catlabel, 1, 2, 0, 1, 
+  gtk_table_attach(GTK_TABLE(detailtable), s->location, 1, 2, 0, 1, 
                    GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(detailtable), descriptionlabel, 0, 1, 1, 2, 
+  gtk_table_attach(GTK_TABLE(detailtable), catbutton, 0, 1, 1, 2, 
                    GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(detailtable), description, 0, 2, 2, 3, 
+  gtk_table_attach(GTK_TABLE(detailtable), catlabel, 1, 2, 1, 2, 
+                   GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+  gtk_table_attach(GTK_TABLE(detailtable), descriptionlabel, 0, 1, 2, 3, 
+                   GTK_FILL, GTK_FILL, 0, 0);
+  gtk_table_attach(GTK_TABLE(detailtable), description, 0, 2, 3, 4, 
                    GTK_FILL, GTK_FILL, 0, 0);
   
   /* Putting the tab together */
@@ -1617,6 +1634,7 @@ edit_event (event_t ev)
       gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (s->description)),
 				evd->description ? evd->description : "", -1);
       gtk_entry_set_text (GTK_ENTRY (s->summary), evd->summary ? evd->summary : "");
+      gtk_entry_set_text (GTK_ENTRY (s->location), evd->location ? evd->location : "");
       update_categories (w, evd->categories, s);
       event_db_forget_details (ev);
 
@@ -1645,7 +1663,7 @@ edit_event (event_t ev)
  
       if (ev->flags & FLAG_ALARM)
         {
-	  unsigned int unit = 0;	/* minutes */
+          unsigned int unit = 0;	/* minutes */
 
           gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (s->alarmbutton), TRUE);
 
@@ -1654,10 +1672,10 @@ edit_event (event_t ev)
 	      unsigned int i;
 
 	      for (i = 0; i < 4; i++)
-		{
-		  if ((ev->alarm % alarm_multipliers[i]) == 0)
-		    unit = i;
-		}
+            {
+		      if ((ev->alarm % alarm_multipliers[i]) == 0)
+		        unit = i;
+            }
 	    }
 
           gtk_spin_button_set_value (GTK_SPIN_BUTTON (s->alarmspin), ev->alarm / alarm_multipliers[unit]);
